==> qmmp_1.6.2.orig.tar.bz2: qmmp-1.6.2/src/plugins/General/rgscan/translations/rgscan_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>RGScanDialog</name>
    <message>
        <location filename="../rgscandialog.ui" line="14"/>
        <source>ReplayGain Scanner</source>
        <translation>回放增益扫描器</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="84"/>
        <source>Write track gain/peak</source>
        <translation>写下曲目增益/峰值</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="42"/>
        <source>Title</source>
        <translation>题头</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="47"/>
        <source>Progress</source>
        <translation>进度</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="52"/>
        <source>Track Gain</source>
        <translation>曲目增益</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="57"/>
        <source>Album Gain</source>
        <translation>专辑增益</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="62"/>
        <source>Track Peak</source>
        <translation>曲目峰值</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="67"/>
        <source>Album Peak</source>
        <translation>专辑峰值</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="77"/>
        <source>Skip already scanned files</source>
        <translation>跳过已扫描过得文件</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="113"/>
        <source>Calculate</source>
        <translation>计算</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="120"/>
        <source>Write Tags</source>
        <translation>写标签</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="91"/>
        <source>Write album gain/peak</source>
        <translation>写专辑的增益/峰值</translation>
    </message>
    <message>
        <location filename="../rgscandialog.cpp" line="125"/>
        <location filename="../rgscandialog.cpp" line="230"/>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <location filename="../rgscandialog.cpp" line="135"/>
        <location filename="../rgscandialog.cpp" line="136"/>
        <location filename="../rgscandialog.cpp" line="160"/>
        <location filename="../rgscandialog.cpp" line="225"/>
        <source>%1 dB</source>
        <translation>%1分贝</translation>
    </message>
</context>
<context>
    <name>RGScanFactory</name>
    <message>
        <location filename="../rgscanfactory.cpp" line="28"/>
        <source>ReplayGain Scanner Plugin</source>
        <translation>回放增益扫描器插件</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="49"/>
        <source>About ReplayGain Scanner Plugin</source>
        <translation>关于回放增益扫描器插件</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="50"/>
        <source>ReplayGain Scanner Plugin for Qmmp</source>
        <translation>用于Qmmp播放器的回放增益扫描器插件</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="51"/>
        <source>This plugin scans audio files and gives information for volume normalization</source>
        <translation>本插件扫描音频文件并提供音量正常化的相关信息</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="53"/>
        <source>Based on source code by:</source>
        <translation>基于以下作者的源代码：</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="54"/>
        <source>David Robinson &lt;David@Robinson.org&gt;</source>
        <translation>戴维.罗宾逊 &lt;David@Robinson.org&gt;</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="55"/>
        <source>Glen Sawyer &lt;mp3gain@hotmail.com&gt;</source>
        <translation>格林.索耶尔 &lt;mp3gain@hotmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="56"/>
        <source>Frank Klemm</source>
        <translation>弗兰克.克莱姆</translation>
    </message>
</context>
<context>
    <name>RGScanHelper</name>
    <message>
        <location filename="../rgscanhelper.cpp" line="32"/>
        <source>ReplayGain Scanner</source>
        <translation>回放增益扫描器</translation>
    </message>
    <message>
        <location filename="../rgscanhelper.cpp" line="33"/>
        <source>Meta+R</source>
        <translation>Meta+R</translation>
    </message>
</context>
</TS>

==> qmmp-1.7.9.tar.bz2: qmmp-1.7.9/src/plugins/General/rgscan/translations/rgscan_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>RGScanDialog</name>
    <message>
        <location filename="../rgscandialog.ui" line="14"/>
        <source>ReplayGain Scanner</source>
        <translation>回放增益扫描器</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="84"/>
        <source>Write track gain/peak</source>
        <translation>写下曲目增益/峰值</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="42"/>
        <source>Title</source>
        <translation>题头</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="47"/>
        <source>Progress</source>
        <translation>进度</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="52"/>
        <source>Track Gain</source>
        <translation>曲目增益</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="57"/>
        <source>Album Gain</source>
        <translation>专辑增益</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="62"/>
        <source>Track Peak</source>
        <translation>曲目峰值</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="67"/>
        <source>Album Peak</source>
        <translation>专辑峰值</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="77"/>
        <source>Skip already scanned files</source>
        <translation>跳过已扫描过得文件</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="113"/>
        <source>Calculate</source>
        <translation>计算</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="120"/>
        <source>Write Tags</source>
        <translation>写标签</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="91"/>
        <source>Write album gain/peak</source>
        <translation>写专辑的增益/峰值</translation>
    </message>
    <message>
        <location filename="../rgscandialog.cpp" line="127"/>
        <location filename="../rgscandialog.cpp" line="233"/>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <location filename="../rgscandialog.cpp" line="137"/>
        <location filename="../rgscandialog.cpp" line="138"/>
        <location filename="../rgscandialog.cpp" line="163"/>
        <location filename="../rgscandialog.cpp" line="228"/>
        <source>%1 dB</source>
        <translation>%1分贝</translation>
    </message>
</context>
<context>
    <name>RGScanFactory</name>
    <message>
        <location filename="../rgscanfactory.cpp" line="28"/>
        <source>ReplayGain Scanner Plugin</source>
        <translation>回放增益扫描器插件</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="49"/>
        <source>About ReplayGain Scanner Plugin</source>
        <translation>关于回放增益扫描器插件</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="50"/>
        <source>ReplayGain Scanner Plugin for Qmmp</source>
        <translation>用于Qmmp播放器的回放增益扫描器插件</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="51"/>
        <source>This plugin scans audio files and gives information for volume normalization</source>
        <translation>本插件扫描音频文件并提供音量正常化的相关信息</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="53"/>
        <source>Based on source code by:</source>
        <translation>基于以下作者的源代码：</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="54"/>
        <source>David Robinson &lt;David@Robinson.org&gt;</source>
        <translation>戴维.罗宾逊 &lt;David@Robinson.org&gt;</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="55"/>
        <source>Glen Sawyer &lt;mp3gain@hotmail.com&gt;</source>
        <translation>格林.索耶尔 &lt;mp3gain@hotmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="56"/>
        <source>Frank Klemm</source>
        <translation>弗兰克.克莱姆</translation>
    </message>
</context>
<context>
    <name>RGScanHelper</name>
    <message>
        <location filename="../rgscanhelper.cpp" line="32"/>
        <source>ReplayGain Scanner</source>
        <translation>回放增益扫描器</translation>
    </message>
    <message>
        <location filename="../rgscanhelper.cpp" line="33"/>
        <source>Meta+R</source>
        <translation>Meta+R</translation>
    </message>
</context>
</TS>
